/*
  FUSE: Filesystem in Userspace

  This program can be distributed under the terms of the GNU LGPLv2.
  See the file COPYING.LIB.
*/

#include "fuse_numa.h"

#ifdef HAVE_NUMA_H
int fuse_numa_available(void)
{
	if (numa_available() < 0)
		return 0;
	else
		return 1;
}

int fuse_numa_max_nodes(void)
{
	if (numa_available() < 0)
		return 1;
	else
		return (numa_max_node() + 1);
}

void fuse_numa_run_on_node(int node)
{
	if (node != FUSE_MAX_NUMA_NODE)
		numa_run_on_node(node);
}

void *fuse_numa_alloc(size_t sz, int node)
{
	if (node == FUSE_MAX_NUMA_NODE)
		return malloc(sz);
	else
		return numa_alloc_onnode(sz, node);
}

void fuse_numa_free(void *buf, size_t sz, int node)
{
	if (node == FUSE_MAX_NUMA_NODE)
		free(buf);
	else
		numa_free(buf, sz);
}
#else /* HAVE_NUMA_H */
int fuse_numa_available(void)
{
	return 0;
}

int fuse_numa_max_nodes(void)
{
	return 1;
}

void fuse_numa_run_on_node(int node)
{
	return;
}

void *fuse_numa_alloc(size_t sz, int node)
{
	return malloc(sz);
}

void fuse_numa_free(void *buf, size_t sz, int node)
{
	free(buf);
}
#endif /* HAVE_NUMA_H */
